pub struct SegmentCollation {
pub collation: Collation,
pub relay_parent: Hash,
pub validation_data: PersistedValidationData,
pub validation_code_hash: ValidationCodeHash,
pub session_index: SessionIndex,
}Expand description
A single collation in a segment submitted via CollationGenerationMessage::SubmitSegment.
Fields
collation: CollationThe collation itself (PoV and commitments).
relay_parent: HashThe relay-parent the collation is built against.
validation_data: PersistedValidationDataThe persisted validation data for this collation. The parent_head field must be set
to the correct parent head-data for the parablock being submitted.
validation_code_hash: ValidationCodeHashThe hash of the validation code the collation was created against.
session_index: SessionIndexThe session index of the relay parent. Goes into the candidate descriptor. Must be provided by the caller because the relay parent’s state may be pruned.