pub struct SubmitCollationParams {
pub relay_parent: Hash,
pub collation: Collation,
pub validation_code_hash: ValidationCodeHash,
pub result_sender: Option<Sender<CollationSecondedSignal>>,
pub core_index: CoreIndex,
pub scheduling_parent: Option<Hash>,
pub session_index: SessionIndex,
pub validation_data: PersistedValidationData,
}Expand description
Parameters for CollationGenerationMessage::SubmitCollation.
Fields
relay_parent: HashThe relay-parent the collation is built against.
collation: CollationThe collation itself (PoV and commitments)
validation_code_hash: ValidationCodeHashThe hash of the validation code the collation was created against.
result_sender: Option<Sender<CollationSecondedSignal>>An optional result sender that should be informed about a successfully seconded collation.
There is no guarantee that this sender is informed ever about any result, it is completely okay to just drop it. However, if it is called, it should be called with the signed statement of a parachain validator seconding the collation.
core_index: CoreIndexThe core index on which the resulting candidate should be backed
scheduling_parent: Option<Hash>The scheduling parent for V3 candidate descriptors. If set, the candidate descriptor will use this as the scheduling parent (creating a V3 descriptor). If None, relay_parent is used (V2 descriptor).
WARNING: Should only be set if the CandidateReceiptV3 node feature is set.
session_index: SessionIndexThe session index of the relay parent. Goes into the candidate descriptor. Must be provided by the caller because the relay parent’s state may be pruned.
validation_data: PersistedValidationDataThe persisted validation data for this collation. The parent_head field must be set
to the correct parent head-data for the parablock being submitted.